# Reference

## crazyhusk

```{eval-rst}
.. automodule:: crazyhusk
   :members:
```

### crazyhusk.build

```{eval-rst}
.. automodule:: crazyhusk.build
   :members:
```

### crazyhusk.cli

```{eval-rst}
.. automodule:: crazyhusk.cli
   :members:
```

### crazyhusk.code

```{eval-rst}
.. automodule:: crazyhusk.code
   :members:
```

### crazyhusk.config

```{eval-rst}
.. automodule:: crazyhusk.config
   :members:
```

### crazyhusk.engine

```{eval-rst}
.. automodule:: crazyhusk.engine
   :members:
```

### crazyhusk.logs

```{eval-rst}
.. automodule:: crazyhusk.logs
   :members:
```

### crazyhusk.module

```{eval-rst}
.. automodule:: crazyhusk.module
   :members:
```

### crazyhusk.plugin

```{eval-rst}
.. automodule:: crazyhusk.plugin
   :members:
```

### crazyhusk.project

```{eval-rst}
.. automodule:: crazyhusk.project
   :members:
```

### crazyhusk.reports

```{eval-rst}
.. automodule:: crazyhusk.reports
   :members:
```
